# source function

# a function to generate synthetic read count
GenerateReadCount <- function(fusionNum,toolNum,trueFusionNum,missingRate,seed){
  set.seed(seed)
  
  tab <- matrix(0,fusionNum,toolNum)
  
  for(j in 1:toolNum){
    baseNumber1 <- sample(1:500,1)   # background base number
    baseNumber2 <- round(baseNumber1/4) # trueFusion base number
    
    tab[,j] <- rpois(fusionNum,lambda=baseNumber1)
    tab[1:trueFusionNum,j] <- tab[1:trueFusionNum,j]+rpois(trueFusionNum,lambda=sort(sample(1:baseNumber2,trueFusionNum,replace=T),decreasing=T))
    
    # add missing value
    ind1 <- sample(1:trueFusionNum,round(trueFusionNum*missingRate[j]/1.5)) # true fusion has 2/3  missing rate
    ind2 <- sample((trueFusionNum+1):fusionNum,round((fusionNum-trueFusionNum)*missingRate[j]))
    tab[c(ind1,ind2),j] <- 0
  }
  
  rownames(tab) <- as.vector(outer("fusion",1:fusionNum,paste,sep="_"))
  colnames(tab) <- as.vector(outer("tool",1:toolNum,paste,sep="_"))
  
  trueFusion <- rownames(tab)[1:trueFusionNum]
  
  return(list(countMatrix=tab,trueFusion=trueFusion))
}

# a function to re-rank the fusions
FusionMetaCaller <- function (countMatrix, vote=2, plot=F,trueFusion=NA){
  
  # step 1: filter by vote
  filterInd <- apply(countMatrix>0,1,sum)>=vote
  filterMatrix <- countMatrix[filterInd,]
  
  # step 2: rank within each tool (small to large)  ######### only rank the non-zero term
  orderMatrix<- matrix(0,nrow(filterMatrix),ncol(filterMatrix))
  for(j in 1:ncol(filterMatrix)){
    ind <- filterMatrix[,j]!=0
    orderMatrix[ind,j] <- order(filterMatrix[ind,j])
  }
  rankSum <- apply(orderMatrix,1,sum)
  orderOfRankSum <- order(-rankSum)  # from large to small
  
  sortMatrix <- filterMatrix[orderOfRankSum,]
  
  # precision-recall plot
  if(plot==T){
    
    # parameter setting
    co <- 2    # cutoff interval
    colLabel <- c("red","blue","green","yellow","purple","chocolate1","hotpink","orange","darkblue","darkgreen")
    ltyLabel <- c(rep(c(1,5),each=10))
    
    # mark the truth
    mark <- rep(0,times=nrow(countMatrix))
    mark[rownames(countMatrix)%in%trueFusion] <- 1
    
    pdf("precision_recall_plot.pdf")
    par(mar=c(5.1, 4.1, 4.1, 8.1), xpd=TRUE)
    plot(x=NULL, y=NULL, xlim=c(0,1), ylim=c(0,1), 
         xlab = "Recall", ylab = "Precision", 
         main = "Precison-Recall Plot",
         cex.lab=1.5, cex.axis=1.3)
    
    # plot the single tool 
    for(j in 1:ncol(countMatrix)){
      sortCount <- sort(countMatrix[,j],decreasing=T)
      numFusion <- sum(sortCount>0)
      sortMark <- mark[order(countMatrix[,j],decreasing=T)]
      sortMark <- sortMark[1:numFusion]
      
      # set cutoff
      CUTOFF <- seq(from=1,to=length(sortMark),by=co)
      if(CUTOFF[length(CUTOFF)]!=length(sortMark)){
        CUTOFF <- c(CUTOFF,length(sortMark))
      }
      
      # get precision and recall
      precision <- rep(0,times=length(CUTOFF)) # initialize
      recall <- rep(0,times=length(CUTOFF))
      
      for(i in 1:length(CUTOFF)){
        cutoff <- CUTOFF[i]
        TP <- sum(sortMark[1:cutoff])
        precision[i] <- TP/cutoff
        recall[i] <- TP/length(trueFusion)
      }
      
      # plot
      collabel <- colLabel[j%%10]
      ltylabel <- ltyLabel[j%%20]
      
      lines(recall, precision, col=collabel, lwd = 2,lty=ltylabel)
      
    }
    
    # meta-caller 
    sortMark <- rownames(sortMatrix)%in%trueFusion
    # set cutoff
    CUTOFF <- seq(from=1,to=length(sortMark),by=co)
    if(CUTOFF[length(CUTOFF)]!=length(sortMark)){
      CUTOFF <- c(CUTOFF,length(sortMark))
    }
    
    # get precision and recall
    precision <- rep(0,times=length(CUTOFF)) # initialize
    recall <- rep(0,times=length(CUTOFF))
    
    for(i in 1:length(CUTOFF)){
      cutoff <- CUTOFF[i]
      TP <- sum(sortMark[1:cutoff])
      precision[i] <- TP/cutoff
      recall[i] <- TP/length(trueFusion)
    }
    
    # plot
    collabel <- "black"
    ltylabel <- 2
    
    lines(recall, precision, col=collabel, lwd = 2,lty=ltylabel)
    
    # legend
    legend("topright",inset=c(-0.35,0),legend=c(colnames(countMatrix),"meta-caller"),
           lty=c(rep(ltyLabel,length=ncol(countMatrix)),2),lwd=3,
           col=c(rep(colLabel,length=ncol(countMatrix)),"black"),bty="n")
  
    dev.off()
    
  }
  
  return(list(sortMatrix=sortMatrix))
  
}



