\name{FusionMetaCaller}
\alias{FusionMetaCaller}
\title{
A meta-caller to combine and reprioritize the fusion transcripts detected by multiple tools
}
\description{
Top performing methods likely had complementary advantages to accurately detect different types of fusion events. First of all, we selected fusion events detected by at least a certain number of tools. We next ranked the detected fusion events from each method by the number of supporting reads. Rank sums of the selected fusion events were calculated and the fusion events were reprioritized accordingly.
}
\usage{
FusionMetaCaller(countMatrix, vote, plot, trueFusion)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{countMatrix}{
An integer matrix for supporting read counts with rows representing the fusion events and columns representing the fusion detection tools.
}
  \item{vote}{
Minimum number of supporting tools to keep the fusion events in the combined result. The default value is 2.
}
  \item{plot}{
A boolen variable to indicate whether or not to plot the precision-recall curve. The plot will be saved as `precision_recall_plot.pdf'. The default value is FALSE.
}
  \item{trueFusion}{
A vector to list all the true fusion events. This argument is only needed when plot is TRUE.
}
}

\value{
\item{sortMatrix}{The combined results to reprioritize the fusion events.}
}
\references{
Comprehensive evaluation of fusion transcript detection algorithms and a meta-caller to combine top performing methods in paired-end RNA-seq data. (2015)
Silvia Liu^, Wei-Hsiang Tsai^, Ying Ding^, Rui Chen, Zhou Fang, SungHwan Kim, Tianzhou Ma, Ting-Yu Chang, Jianhua Luo, Hsei-Wei Wang*, I-Fang Chung* and George C. Tseng*.
}
\author{
Silvia Liu <silvia.shuchang.liu@gmail.com>
}

\examples{
## generate synthetic read count matrix
syn <- GenerateReadCount(fusionNum=100,toolNum=5,trueFusionNum=70,missingRate=c(0.4,0.6,0.8,0.8,0.9),seed=12345)
countMatrix <- syn$countMatrix
trueFusion <- syn$trueFusion

## the meta-caller to reprioritize the fusion events
metaRes <- FusionMetaCaller(countMatrix, vote=2)

## plot the precision-recall curve
metaRes <- FusionMetaCaller(countMatrix, vote=2, plot=TRUE,trueFusion)
}
